<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="ru_UA" sourcelanguage="en_US">
<context>
    <name>AlbumDefaultPage</name>
    <message>
        <location filename="../src/music-player/albumlist/AlbumDefaultPage.qml" line="35"/>
        <source>Add Songs</source>
        <translation>Добавить песни</translation>
    </message>
    <message>
        <location filename="../src/music-player/albumlist/AlbumDefaultPage.qml" line="43"/>
        <source>Open Folders</source>
        <translation>Открыть папки</translation>
    </message>
    <message>
        <location filename="../src/music-player/albumlist/AlbumDefaultPage.qml" line="59"/>
        <source>Drag music files here or</source>
        <translation>Перетащите музыкальные файлы сюда или</translation>
    </message>
    <message>
        <location filename="../src/music-player/albumlist/AlbumDefaultPage.qml" line="63"/>
        <source> scan the Music directory</source>
        <translation>сканировать папку Music</translation>
    </message>
</context>
<context>
    <name>AlbumGridDelegate</name>
    <message>
        <location filename="../src/music-player/albumlist/AlbumGridDelegate.qml" line="116"/>
        <source>1 song</source>
        <translation>1 песня</translation>
    </message>
    <message>
        <location filename="../src/music-player/albumlist/AlbumGridDelegate.qml" line="116"/>
        <source>%1 songs</source>
        <translation>%1 песен</translation>
    </message>
</context>
<context>
    <name>AlbumListDelegate</name>
    <message>
        <location filename="../src/music-player/albumlist/AlbumListDelegate.qml" line="107"/>
        <source>%1</source>
        <translation>%1</translation>
    </message>
</context>
<context>
    <name>AlbumListView</name>
    <message>
        <location filename="../src/music-player/albumlist/AlbumListView.qml" line="33"/>
        <source>Album</source>
        <translation>Альбом</translation>
    </message>
    <message>
        <location filename="../src/music-player/albumlist/AlbumListView.qml" line="38"/>
        <source>Artist</source>
        <translation>Исполнитель</translation>
    </message>
    <message>
        <location filename="../src/music-player/albumlist/AlbumListView.qml" line="43"/>
        <source>Tracks</source>
        <translation>Треки</translation>
    </message>
    <message>
        <location filename="../src/music-player/albumlist/AlbumListView.qml" line="48"/>
        <source>Date added</source>
        <translation>Дата добавления</translation>
    </message>
</context>
<context>
    <name>AlbumMoreMenu</name>
    <message>
        <location filename="../src/music-player/musicmousemenu/AlbumMoreMenu.qml" line="20"/>
        <source>View details</source>
        <translation>Посмотреть детали</translation>
    </message>
    <message>
        <location filename="../src/music-player/musicmousemenu/AlbumMoreMenu.qml" line="28"/>
        <source>Play all</source>
        <translation>Воспроизвести все</translation>
    </message>
    <message>
        <location filename="../src/music-player/musicmousemenu/AlbumMoreMenu.qml" line="37"/>
        <source>Add to</source>
        <translation>Добавить в</translation>
    </message>
</context>
<context>
    <name>AlbumSublist</name>
    <message>
        <location filename="../src/music-player/musicsublist/AlbumSublist.qml" line="36"/>
        <source>Title</source>
        <translation>Название</translation>
    </message>
    <message>
        <location filename="../src/music-player/musicsublist/AlbumSublist.qml" line="41"/>
        <source>Artist</source>
        <translation>Исполнитель</translation>
    </message>
    <message>
        <location filename="../src/music-player/musicsublist/AlbumSublist.qml" line="46"/>
        <source>Duration</source>
        <translation>Продолжительность</translation>
    </message>
</context>
<context>
    <name>AlbumSublistDelegate</name>
    <message>
        <location filename="../src/music-player/musicsublist/AlbumSublistDelegate.qml" line="147"/>
        <source>My Favorites</source>
        <translation>Мои избранные</translation>
    </message>
</context>
<context>
    <name>AlbumSublistView</name>
    <message>
        <location filename="../src/music-player/musicsublist/AlbumSublistView.qml" line="55"/>
        <source>Title</source>
        <translation>Название</translation>
    </message>
    <message>
        <location filename="../src/music-player/musicsublist/AlbumSublistView.qml" line="60"/>
        <source>Artist</source>
        <translation>Исполнитель</translation>
    </message>
    <message>
        <location filename="../src/music-player/musicsublist/AlbumSublistView.qml" line="66"/>
        <source>Duration</source>
        <translation>Продолжительность</translation>
    </message>
</context>
<context>
    <name>AlbumView</name>
    <message>
        <location filename="../src/music-player/albumlist/AlbumView.qml" line="54"/>
        <source>Albums</source>
        <translation>Альбомы</translation>
    </message>
    <message>
        <location filename="../src/music-player/albumlist/AlbumView.qml" line="55"/>
        <source>%1 albums - %2 songs</source>
        <translation>%1 альбомов - %2 песен</translation>
    </message>
</context>
<context>
    <name>AllMusicDefaultPage</name>
    <message>
        <location filename="../src/music-player/musicList/AllMusicDefaultPage.qml" line="42"/>
        <source>Add Songs</source>
        <translation>Добавить песни</translation>
    </message>
    <message>
        <location filename="../src/music-player/musicList/AllMusicDefaultPage.qml" line="50"/>
        <source>Open Folders</source>
        <translation>Открыть папки</translation>
    </message>
    <message>
        <location filename="../src/music-player/musicList/AllMusicDefaultPage.qml" line="65"/>
        <source>Drag music files here or</source>
        <translation>Перетащите музыкальные файлы сюда или</translation>
    </message>
    <message>
        <location filename="../src/music-player/musicList/AllMusicDefaultPage.qml" line="99"/>
        <source>Your favorite songs will be displayed here</source>
        <translation>Ваши любимые песни будут отображены здесь</translation>
    </message>
    <message>
        <location filename="../src/music-player/musicList/AllMusicDefaultPage.qml" line="111"/>
        <source>Click “</source>
        <translation>Нажмите “</translation>
    </message>
    <message>
        <location filename="../src/music-player/musicList/AllMusicDefaultPage.qml" line="122"/>
        <source>” to add a song to My Favorites</source>
        <translation>” чтобы добавить песню в Мои избранные</translation>
    </message>
    <message>
        <location filename="../src/music-player/musicList/AllMusicDefaultPage.qml" line="157"/>
        <source>No songs yet. Click “</source>
        <translation>Еще нет песен. Нажмите “</translation>
    </message>
    <message>
        <location filename="../src/music-player/musicList/AllMusicDefaultPage.qml" line="168"/>
        <source>” to add songs to the playlist</source>
        <translation>чтобы добавить песни в плейлист</translation>
    </message>
    <message>
        <location filename="../src/music-player/musicList/AllMusicDefaultPage.qml" line="69"/>
        <source> scan the Music directory</source>
        <translation>сканировать музыкальную папку</translation>
    </message>
</context>
<context>
    <name>AllMusicList</name>
    <message>
        <location filename="../src/music-player/musicList/AllMusicList.qml" line="17"/>
        <source>All Songs</source>
        <translation>Все песни</translation>
    </message>
    <message>
        <location filename="../src/music-player/musicList/AllMusicList.qml" line="30"/>
        <source>1 song</source>
        <translation>1 песня</translation>
    </message>
    <message>
        <location filename="../src/music-player/musicList/AllMusicList.qml" line="30"/>
        <source>%1 songs</source>
        <translation>%1 песен</translation>
    </message>
</context>
<context>
    <name>AllMusicListDelegate</name>
    <message>
        <location filename="../src/music-player/musicList/AllMusicListDelegate.qml" line="212"/>
        <source>My Favorites</source>
        <translation>Мои избранные</translation>
    </message>
</context>
<context>
    <name>AllMusicListView</name>
    <message>
        <location filename="../src/music-player/musicList/AllMusicListView.qml" line="38"/>
        <source>Title</source>
        <translation>Название</translation>
    </message>
    <message>
        <location filename="../src/music-player/musicList/AllMusicListView.qml" line="44"/>
        <source>Artist</source>
        <translation>Исполнитель</translation>
    </message>
    <message>
        <location filename="../src/music-player/musicList/AllMusicListView.qml" line="49"/>
        <source>Album</source>
        <translation>Альбом</translation>
    </message>
    <message>
        <location filename="../src/music-player/musicList/AllMusicListView.qml" line="54"/>
        <source>Duration</source>
        <translation>Длительность</translation>
    </message>
</context>
<context>
    <name>ArtistDefaultPage</name>
    <message>
        <location filename="../src/music-player/singerlist/ArtistDefaultPage.qml" line="36"/>
        <source>Add Songs</source>
        <translation>Добавить песни</translation>
    </message>
    <message>
        <location filename="../src/music-player/singerlist/ArtistDefaultPage.qml" line="44"/>
        <source>Open Folders</source>
        <translation>Открыть папки</translation>
    </message>
    <message>
        <location filename="../src/music-player/singerlist/ArtistDefaultPage.qml" line="60"/>
        <source>Drag music files here or</source>
        <translation>Перетащите музыкальные файлы сюда или</translation>
    </message>
    <message>
        <location filename="../src/music-player/singerlist/ArtistDefaultPage.qml" line="64"/>
        <source> scan the Music directory</source>
        <translation>сканировать музыкальную папку</translation>
    </message>
</context>
<context>
    <name>ArtistGridDelegate</name>
    <message>
        <location filename="../src/music-player/singerlist/ArtistGridDelegate.qml" line="149"/>
        <source>1 song</source>
        <translation>1 песня</translation>
    </message>
    <message>
        <location filename="../src/music-player/singerlist/ArtistGridDelegate.qml" line="149"/>
        <source>%1 songs</source>
        <translation>%1 песен</translation>
    </message>
</context>
<context>
    <name>ArtistMoreMenu</name>
    <message>
        <location filename="../src/music-player/musicmousemenu/ArtistMoreMenu.qml" line="18"/>
        <source>View details</source>
        <translation>Посмотреть детали</translation>
    </message>
    <message>
        <location filename="../src/music-player/musicmousemenu/ArtistMoreMenu.qml" line="26"/>
        <source>Play all</source>
        <translation>Воспроизвести все</translation>
    </message>
    <message>
        <location filename="../src/music-player/musicmousemenu/ArtistMoreMenu.qml" line="35"/>
        <source>Add to</source>
        <translation>Добавить в</translation>
    </message>
</context>
<context>
    <name>ArtistSublistDelegate</name>
    <message>
        <location filename="../src/music-player/musicsublist/ArtistSublistDelegate.qml" line="102"/>
        <source>My Favorites</source>
        <translation>Мои избранные</translation>
    </message>
</context>
<context>
    <name>ArtistSublistView</name>
    <message>
        <location filename="../src/music-player/musicsublist/ArtistSublistView.qml" line="59"/>
        <source>Title</source>
        <translation>Название</translation>
    </message>
    <message>
        <location filename="../src/music-player/musicsublist/ArtistSublistView.qml" line="65"/>
        <source>Album</source>
        <translation>Альбом</translation>
    </message>
    <message>
        <location filename="../src/music-player/musicsublist/ArtistSublistView.qml" line="70"/>
        <source>Duration</source>
        <translation>Длительность</translation>
    </message>
</context>
<context>
    <name>ArtistView</name>
    <message>
        <location filename="../src/music-player/singerlist/ArtistView.qml" line="54"/>
        <source>Artists</source>
        <translation>Исполнители</translation>
    </message>
    <message>
        <location filename="../src/music-player/singerlist/ArtistView.qml" line="55"/>
        <source>%1 artists - %2 songs</source>
        <translation>%1 исполнителей - %2 песен</translation>
    </message>
</context>
<context>
    <name>CDRemovedDialog</name>
    <message>
        <location filename="../src/music-player/dialogs/CDRemovedDialog.qml" line="32"/>
        <source>The CD has been removed</source>
        <translation>Диск был удален</translation>
    </message>
    <message>
        <location filename="../src/music-player/dialogs/CDRemovedDialog.qml" line="36"/>
        <source>Cancel</source>
        <translation>Отмена</translation>
    </message>
</context>
<context>
    <name>CloseConfirmDialog</name>
    <message>
        <location filename="../src/music-player/dialogs/CloseConfirmDialog.qml" line="36"/>
        <source>Please choose your action</source>
        <translation>Пожалуйста, выберите действие</translation>
    </message>
    <message>
        <location filename="../src/music-player/dialogs/CloseConfirmDialog.qml" line="50"/>
        <source>Minimize to system tray</source>
        <translation>Свернуть в системный трей</translation>
    </message>
    <message>
        <location filename="../src/music-player/dialogs/CloseConfirmDialog.qml" line="62"/>
        <source>Exit</source>
        <translation>Выйти</translation>
    </message>
    <message>
        <location filename="../src/music-player/dialogs/CloseConfirmDialog.qml" line="73"/>
        <source>Do not ask again</source>
        <translation>Не спрашивать снова</translation>
    </message>
    <message>
        <location filename="../src/music-player/dialogs/CloseConfirmDialog.qml" line="90"/>
        <source>Cancel</source>
        <translation>Отмена</translation>
    </message>
    <message>
        <location filename="../src/music-player/dialogs/CloseConfirmDialog.qml" line="98"/>
        <source>Confirm</source>
        <translation>Подтвердить</translation>
    </message>
</context>
<context>
    <name>CurrentPlayList</name>
    <message>
        <location filename="../src/music-player/playlist/CurrentPlayList.qml" line="97"/>
        <source>Play queue</source>
        <translation>Плеер</translation>
    </message>
    <message>
        <location filename="../src/music-player/playlist/CurrentPlayList.qml" line="114"/>
        <source>1 song</source>
        <translation>1 песня</translation>
    </message>
    <message>
        <location filename="../src/music-player/playlist/CurrentPlayList.qml" line="114"/>
        <source>%1 songs</source>
        <translation>&apos;%1 песен&apos;</translation>
    </message>
    <message>
        <location filename="../src/music-player/playlist/CurrentPlayList.qml" line="128"/>
        <source>Empty</source>
        <translation>Пустой</translation>
    </message>
</context>
<context>
    <name>CurrentPlayListDelegate</name>
    <message>
        <location filename="../src/music-player/playlist/CurrentPlayListDelegate.qml" line="123"/>
        <source>My Favorites</source>
        <translation>Мои избранные</translation>
    </message>
</context>
<context>
    <name>CustomPlaylistModel</name>
    <message>
        <location filename="../src/music-player/musicbaseandsonglist/CustomPlaylistModel.qml" line="23"/>
        <source>My Favorites</source>
        <translation>Список CD</translation>
    </message>
    <message>
        <location filename="../src/music-player/musicbaseandsonglist/CustomPlaylistModel.qml" line="80"/>
        <source>CD playlist</source>
        <translation>CD</translation>
    </message>
    <message>
        <location filename="../src/music-player/musicbaseandsonglist/CustomPlaylistModel.qml" line="86"/>
        <source>CD</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>DeleteLocalDialog</name>
    <message>
        <location filename="../src/music-player/dialogs/DeleteLocalDialog.qml" line="34"/>
        <source>Are you sure you want to delete %1?</source>
        <translation>Вы уверены, что хотите удалить выбранные %1 песен?</translation>
    </message>
    <message>
        <location filename="../src/music-player/dialogs/DeleteLocalDialog.qml" line="36"/>
        <source>Are you sure you want to delete the selected %1 songs?</source>
        <translation>Файлы песен, содержащиеся в списке, также будут удалены</translation>
    </message>
    <message>
        <location filename="../src/music-player/dialogs/DeleteLocalDialog.qml" line="45"/>
        <source>The song files contained will also be deleted</source>
        <translation>Удалить</translation>
    </message>
    <message>
        <location filename="../src/music-player/dialogs/DeleteLocalDialog.qml" line="53"/>
        <source>Delete</source>
        <translation>Отмена</translation>
    </message>
    <message>
        <location filename="../src/music-player/dialogs/DeleteLocalDialog.qml" line="65"/>
        <source>Cancel</source>
        <translation>Вы уверены, что хотите удалить %1?</translation>
    </message>
</context>
<context>
    <name>DeleteSonglistDialog</name>
    <message>
        <location filename="../src/music-player/dialogs/DeleteSonglistDialog.qml" line="41"/>
        <source>Are you sure you want to remove %1?</source>
        <translation>Вы уверены, что хотите удалить выбранные %1 песен?</translation>
    </message>
    <message>
        <location filename="../src/music-player/dialogs/DeleteSonglistDialog.qml" line="43"/>
        <source>Are you sure you want to remove the selected %1 songs?</source>
        <translation>Вы уверены, что хотите удалить этот плейлист?</translation>
    </message>
    <message>
        <location filename="../src/music-player/dialogs/DeleteSonglistDialog.qml" line="45"/>
        <source>Are you sure you want to delete this playlist?</source>
        <translation>Удалить</translation>
    </message>
    <message>
        <location filename="../src/music-player/dialogs/DeleteSonglistDialog.qml" line="55"/>
        <source>Remove</source>
        <translation>Удалить</translation>
    </message>
    <message>
        <location filename="../src/music-player/dialogs/DeleteSonglistDialog.qml" line="55"/>
        <source>Delete</source>
        <translation>Отмена</translation>
    </message>
    <message>
        <location filename="../src/music-player/dialogs/DeleteSonglistDialog.qml" line="70"/>
        <source>Cancel</source>
        <translation>Пользовательский</translation>
    </message>
</context>
<context>
    <name>EqualizerDialog</name>
    <message>
        <location filename="../src/music-player/dialogs/EqualizerDialog.qml" line="14"/>
        <source>Custom</source>
        <translation>Моноприз</translation>
    </message>
    <message>
        <location filename="../src/music-player/dialogs/EqualizerDialog.qml" line="15"/>
        <source>Monophony</source>
        <translation>Классика</translation>
    </message>
    <message>
        <location filename="../src/music-player/dialogs/EqualizerDialog.qml" line="16"/>
        <source>Classical</source>
        <translation>Клуб</translation>
    </message>
    <message>
        <location filename="../src/music-player/dialogs/EqualizerDialog.qml" line="17"/>
        <source>Club</source>
        <translation>Танец</translation>
    </message>
    <message>
        <location filename="../src/music-player/dialogs/EqualizerDialog.qml" line="18"/>
        <source>Dance</source>
        <translation>Громкий бас</translation>
    </message>
    <message>
        <location filename="../src/music-player/dialogs/EqualizerDialog.qml" line="19"/>
        <source>Full Bass</source>
        <translation>Громкий бас и treble</translation>
    </message>
    <message>
        <location filename="../src/music-player/dialogs/EqualizerDialog.qml" line="20"/>
        <source>Full Bass and Treble</source>
        <translation>Громкий treble</translation>
    </message>
    <message>
        <location filename="../src/music-player/dialogs/EqualizerDialog.qml" line="21"/>
        <source>Full Treble</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/music-player/dialogs/EqualizerDialog.qml" line="22"/>
        <source>Headphones</source>
        <translation>Наушники</translation>
    </message>
    <message>
        <location filename="../src/music-player/dialogs/EqualizerDialog.qml" line="23"/>
        <source>Hall</source>
        <translation>Зал</translation>
    </message>
    <message>
        <location filename="../src/music-player/dialogs/EqualizerDialog.qml" line="24"/>
        <source>Live</source>
        <translation>Живой</translation>
    </message>
    <message>
        <location filename="../src/music-player/dialogs/EqualizerDialog.qml" line="25"/>
        <source>Party</source>
        <translation>Паці</translation>
    </message>
    <message>
        <location filename="../src/music-player/dialogs/EqualizerDialog.qml" line="26"/>
        <source>Pop</source>
        <translation>Поп</translation>
    </message>
    <message>
        <location filename="../src/music-player/dialogs/EqualizerDialog.qml" line="27"/>
        <source>Reggae</source>
        <translation>Реггей</translation>
    </message>
    <message>
        <location filename="../src/music-player/dialogs/EqualizerDialog.qml" line="28"/>
        <source>Rock</source>
        <translation>Рок</translation>
    </message>
    <message>
        <location filename="../src/music-player/dialogs/EqualizerDialog.qml" line="29"/>
        <source>Ska</source>
        <translation>Ска</translation>
    </message>
    <message>
        <location filename="../src/music-player/dialogs/EqualizerDialog.qml" line="30"/>
        <source>Soft</source>
        <translation>Мягкий</translation>
    </message>
    <message>
        <location filename="../src/music-player/dialogs/EqualizerDialog.qml" line="31"/>
        <source>Soft Rock</source>
        <translation>Мягкий рок</translation>
    </message>
    <message>
        <location filename="../src/music-player/dialogs/EqualizerDialog.qml" line="32"/>
        <source>Techno</source>
        <translation>Техно</translation>
    </message>
    <message>
        <location filename="../src/music-player/dialogs/EqualizerDialog.qml" line="106"/>
        <source>Equalizer</source>
        <translation>Эквалайзер</translation>
    </message>
    <message>
        <location filename="../src/music-player/dialogs/EqualizerDialog.qml" line="182"/>
        <source>Save</source>
        <translation>Сохранить</translation>
    </message>
    <message>
        <location filename="../src/music-player/dialogs/EqualizerDialog.qml" line="205"/>
        <source>Reset</source>
        <translation>Сбросить</translation>
    </message>
    <message>
        <location filename="../src/music-player/dialogs/EqualizerDialog.qml" line="314"/>
        <source>Preamplifier</source>
        <translation>Предусилитель</translation>
    </message>
</context>
<context>
    <name>FileDialog</name>
    <message>
        <location filename="../src/music-player/dialogs/FileDialog.qml" line="15"/>
        <source>All Music</source>
        <translation>Все музыка</translation>
    </message>
</context>
<context>
    <name>ImportFailedDialog</name>
    <message>
        <location filename="../src/music-player/dialogs/ImportFailedDialog.qml" line="32"/>
        <source>Import failed, no valid music file found</source>
        <translation>Импорт не удался, не найден действительный музыкальный файл</translation>
    </message>
    <message>
        <location filename="../src/music-player/dialogs/ImportFailedDialog.qml" line="36"/>
        <source>OK</source>
        <translation>ОК</translation>
    </message>
</context>
<context>
    <name>ImportMenu</name>
    <message>
        <location filename="../src/music-player/musicmousemenu/ImportMenu.qml" line="25"/>
        <source>Play queue</source>
        <translation>Плейлист</translation>
    </message>
    <message>
        <location filename="../src/music-player/musicmousemenu/ImportMenu.qml" line="40"/>
        <source>My favorites</source>
        <translation>Мои избранные</translation>
    </message>
    <message>
        <location filename="../src/music-player/musicmousemenu/ImportMenu.qml" line="49"/>
        <source>Create new playlist</source>
        <translation>Создать новый плейлист</translation>
    </message>
    <message>
        <location filename="../src/music-player/musicmousemenu/ImportMenu.qml" line="52"/>
        <source>New playlist</source>
        <translation>Новый плейлист</translation>
    </message>
</context>
<context>
    <name>LyricPage</name>
    <message>
        <location filename="../src/music-player/lyric/LyricPage.qml" line="133"/>
        <source>Artist</source>
        <translation>Исполнитель</translation>
    </message>
    <message>
        <location filename="../src/music-player/lyric/LyricPage.qml" line="141"/>
        <source>Album</source>
        <translation>Альбом</translation>
    </message>
    <message>
        <location filename="../src/music-player/lyric/LyricPage.qml" line="179"/>
        <source>No lyrics found</source>
        <translation>Лирики не найдены</translation>
    </message>
    <message>
        <location filename="../src/music-player/lyric/LyricPage.qml" line="189"/>
        <source>Please put the lyric file (same name as the song) and the song file in the same folder</source>
        <translation>Пожалуйста, поместите файл лирики (такой же, как у песни) и файл песни в один и тот же папку</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../src/music-player/mainwindow/MainWindow.qml" line="188"/>
        <source>Music</source>
        <translation>Музыка</translation>
    </message>
    <message>
        <location filename="../src/music-player/mainwindow/MainWindow.qml" line="203"/>
        <source>Play/Pause</source>
        <translation>Поставить/приостановить</translation>
    </message>
    <message>
        <location filename="../src/music-player/mainwindow/MainWindow.qml" line="207"/>
        <source>Previous</source>
        <translation>Предыдущая</translation>
    </message>
    <message>
        <location filename="../src/music-player/mainwindow/MainWindow.qml" line="218"/>
        <source>Next</source>
        <translation>Следующая</translation>
    </message>
    <message>
        <location filename="../src/music-player/mainwindow/MainWindow.qml" line="229"/>
        <source>Exit</source>
        <translation>Выход</translation>
    </message>
    <message>
        <location filename="../src/music-player/mainwindow/MainWindow.qml" line="343"/>
        <source>Already added to the playlist</source>
        <translation>Уже добавлен в плейлист</translation>
    </message>
    <message>
        <location filename="../src/music-player/mainwindow/MainWindow.qml" line="346"/>
        <source>Added to &quot;%1&quot;</source>
        <translation>Добавлен в &quot;%1&quot;</translation>
    </message>
    <message>
        <location filename="../src/music-player/mainwindow/MainWindow.qml" line="349"/>
        <source>Removed from &quot;My Favorites&quot;</source>
        <translation>Удалён из &quot;Избранные&quot;</translation>
    </message>
    <message>
        <location filename="../src/music-player/mainwindow/MainWindow.qml" line="352"/>
        <source>A disc is connected</source>
        <translation>Подключен диск</translation>
    </message>
    <message>
        <location filename="../src/music-player/mainwindow/MainWindow.qml" line="368"/>
        <source>My Favorites</source>
        <translation>Избранные</translation>
    </message>
    <message>
        <location filename="../src/music-player/mainwindow/MainWindow.qml" line="390"/>
        <source>All Songs</source>
        <translation>Все песни</translation>
    </message>
</context>
<context>
    <name>MulitSelectMenu</name>
    <message>
        <location filename="../src/music-player/musicmousemenu/MulitSelectMenu.qml" line="19"/>
        <source>Add to</source>
        <translation>Добавить в</translation>
    </message>
    <message>
        <location filename="../src/music-player/musicmousemenu/MulitSelectMenu.qml" line="28"/>
        <source>Remove from playlist</source>
        <translation>Удалить из плейлиста</translation>
    </message>
    <message>
        <location filename="../src/music-player/musicmousemenu/MulitSelectMenu.qml" line="28"/>
        <source>Remove from play queue</source>
        <translation>Удалить из очереди воспроизведения</translation>
    </message>
    <message>
        <location filename="../src/music-player/musicmousemenu/MulitSelectMenu.qml" line="35"/>
        <source>Delete from local disk</source>
        <translation>Удалить с локального диска</translation>
    </message>
</context>
<context>
    <name>MusicBaselistview</name>
    <message>
        <location filename="../src/music-player/musicbaseandsonglist/MusicBaselistview.qml" line="36"/>
        <source>Library</source>
        <translation>Библиотека</translation>
    </message>
    <message>
        <location filename="../src/music-player/musicbaseandsonglist/MusicBaselistview.qml" line="40"/>
        <source>Albums</source>
        <translation>Альбомы</translation>
    </message>
    <message>
        <location filename="../src/music-player/musicbaseandsonglist/MusicBaselistview.qml" line="41"/>
        <source>Artists</source>
        <translation>Исполнители</translation>
    </message>
    <message>
        <location filename="../src/music-player/musicbaseandsonglist/MusicBaselistview.qml" line="42"/>
        <source>All Songs</source>
        <translation>Все песни</translation>
    </message>
    <message>
        <location filename="../src/music-player/musicbaseandsonglist/MusicBaselistview.qml" line="47"/>
        <source>Playlists</source>
        <translation>Плейлисты</translation>
    </message>
    <message>
        <location filename="../src/music-player/musicbaseandsonglist/MusicBaselistview.qml" line="64"/>
        <source>Create playlist</source>
        <translation>Создать плейлист</translation>
    </message>
    <message>
        <location filename="../src/music-player/musicbaseandsonglist/MusicBaselistview.qml" line="66"/>
        <source>New playlist</source>
        <translation>Новый плейлист</translation>
    </message>
</context>
<context>
    <name>MusicContentWindow</name>
    <message>
        <location filename="../src/music-player/mainwindow/MusicContentWindow.qml" line="22"/>
        <source>My Favorites</source>
        <translation>Избранные</translation>
    </message>
</context>
<context>
    <name>MusicInfoDialog</name>
    <message>
        <location filename="../src/music-player/dialogs/MusicInfoDialog.qml" line="71"/>
        <source>Title</source>
        <translation>Название</translation>
    </message>
    <message>
        <location filename="../src/music-player/dialogs/MusicInfoDialog.qml" line="80"/>
        <source>Artist</source>
        <translation>Исполнитель</translation>
    </message>
    <message>
        <location filename="../src/music-player/dialogs/MusicInfoDialog.qml" line="86"/>
        <source>Album</source>
        <translation>Альбом</translation>
    </message>
    <message>
        <location filename="../src/music-player/dialogs/MusicInfoDialog.qml" line="95"/>
        <source>Type</source>
        <translation>Тип</translation>
    </message>
    <message>
        <location filename="../src/music-player/dialogs/MusicInfoDialog.qml" line="101"/>
        <source>Size</source>
        <translation>Размер</translation>
    </message>
    <message>
        <location filename="../src/music-player/dialogs/MusicInfoDialog.qml" line="107"/>
        <source>Duration</source>
        <translation>Продолжительность</translation>
    </message>
    <message>
        <location filename="../src/music-player/dialogs/MusicInfoDialog.qml" line="114"/>
        <source>Path</source>
        <translation>Путь</translation>
    </message>
</context>
<context>
    <name>MusicMoreMenu</name>
    <message>
        <location filename="../src/music-player/musicmousemenu/MusicMoreMenu.qml" line="24"/>
        <source>Pause</source>
        <translation>Пауза</translation>
    </message>
    <message>
        <location filename="../src/music-player/musicmousemenu/MusicMoreMenu.qml" line="24"/>
        <source>Play</source>
        <translation>Воспроизвести</translation>
    </message>
    <message>
        <location filename="../src/music-player/musicmousemenu/MusicMoreMenu.qml" line="44"/>
        <source>Add to</source>
        <translation>Добавить в</translation>
    </message>
    <message>
        <location filename="../src/music-player/musicmousemenu/MusicMoreMenu.qml" line="52"/>
        <source>Open in file manager</source>
        <translation>Открыть в файловом менеджере</translation>
    </message>
    <message>
        <location filename="../src/music-player/musicmousemenu/MusicMoreMenu.qml" line="62"/>
        <source>Remove from playlist</source>
        <translation>Удалить из плейлиста</translation>
    </message>
    <message>
        <location filename="../src/music-player/musicmousemenu/MusicMoreMenu.qml" line="62"/>
        <source>Remove from play queue</source>
        <translation>Удалить из очереди воспроизведения</translation>
    </message>
    <message>
        <location filename="../src/music-player/musicmousemenu/MusicMoreMenu.qml" line="72"/>
        <source>Delete from local disk</source>
        <translation>Удалить с локального диска</translation>
    </message>
    <message>
        <location filename="../src/music-player/musicmousemenu/MusicMoreMenu.qml" line="79"/>
        <source>Encoding</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/music-player/musicmousemenu/MusicMoreMenu.qml" line="104"/>
        <source>Song info</source>
        <translation>Информация о песне</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../src/music-player/main.cpp" line="131"/>
        <source>Music is a local music player with beautiful design and simple functions.</source>
        <translation>Музыка — это локальный проигрыватель музыки с красивым дизайном и простыми функциями.</translation>
    </message>
    <message>
        <location filename="../src/music-player/main.cpp" line="133"/>
        <source>Music</source>
        <translation>Музыка</translation>
    </message>
    <message>
        <location filename="../src/music-player/main.cpp" line="143"/>
        <source>Unknown album</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/music-player/main.cpp" line="143"/>
        <source>Unknown artist</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>SearchResultDialog</name>
    <message>
        <location filename="../src/music-player/dialogs/SearchResultDialog.qml" line="27"/>
        <source>Songs</source>
        <translation>Песни</translation>
    </message>
    <message>
        <location filename="../src/music-player/dialogs/SearchResultDialog.qml" line="39"/>
        <source>Artists</source>
        <translation>Исполнители</translation>
    </message>
    <message>
        <location filename="../src/music-player/dialogs/SearchResultDialog.qml" line="50"/>
        <source>Albums</source>
        <translation>Альбомы</translation>
    </message>
</context>
<context>
    <name>SearchResultWindow</name>
    <message>
        <location filename="../src/music-player/mainwindow/SearchResultWindow.qml" line="55"/>
        <source>No search results</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/music-player/mainwindow/SearchResultWindow.qml" line="95"/>
        <source>Search Results</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/music-player/mainwindow/SearchResultWindow.qml" line="100"/>
        <source>%1 albums - %2 songs</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/music-player/mainwindow/SearchResultWindow.qml" line="101"/>
        <source>1 album - 1 song</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/music-player/mainwindow/SearchResultWindow.qml" line="101"/>
        <source>%1 album - %2 songs</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/music-player/mainwindow/SearchResultWindow.qml" line="120"/>
        <source>Music</source>
        <translation>Музыка</translation>
    </message>
    <message>
        <location filename="../src/music-player/mainwindow/SearchResultWindow.qml" line="128"/>
        <source>Artist</source>
        <translation>Исполнитель</translation>
    </message>
    <message>
        <location filename="../src/music-player/mainwindow/SearchResultWindow.qml" line="124"/>
        <source>Album</source>
        <translation>Альбом</translation>
    </message>
</context>
<context>
    <name>SettingsDialog</name>
    <message>
        <location filename="../src/music-player/dialogs/SettingsDialog.qml" line="30"/>
        <source>Basic</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/music-player/dialogs/SettingsDialog.qml" line="34"/>
        <source>Play</source>
        <translation>Воспроизвести</translation>
    </message>
    <message>
        <location filename="../src/music-player/dialogs/SettingsDialog.qml" line="42"/>
        <source>Autoplay</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/music-player/dialogs/SettingsDialog.qml" line="53"/>
        <source>Remember playback position on exit</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/music-player/dialogs/SettingsDialog.qml" line="66"/>
        <source>Enable fade in/out</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/music-player/dialogs/SettingsDialog.qml" line="78"/>
        <source>Close Main Window</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/music-player/dialogs/SettingsDialog.qml" line="91"/>
        <source>Minimize to system tray</source>
        <translation>Свернуть в системный трей</translation>
    </message>
    <message>
        <location filename="../src/music-player/dialogs/SettingsDialog.qml" line="98"/>
        <source>Exit</source>
        <translation>Выйти</translation>
    </message>
    <message>
        <location filename="../src/music-player/dialogs/SettingsDialog.qml" line="105"/>
        <source>Ask me always</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/music-player/dialogs/SettingsDialog.qml" line="137"/>
        <source>Shortcuts</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/music-player/dialogs/SettingsDialog.qml" line="158"/>
        <source>Play/Pause</source>
        <translation>Воспроизвести/Пауза</translation>
    </message>
    <message>
        <location filename="../src/music-player/dialogs/SettingsDialog.qml" line="201"/>
        <source>Previous</source>
        <translation>Предыдущий</translation>
    </message>
    <message>
        <location filename="../src/music-player/dialogs/SettingsDialog.qml" line="245"/>
        <source>Next</source>
        <translation>Следующий</translation>
    </message>
    <message>
        <location filename="../src/music-player/dialogs/SettingsDialog.qml" line="290"/>
        <source>Volume up</source>
        <translation>Громче</translation>
    </message>
    <message>
        <location filename="../src/music-player/dialogs/SettingsDialog.qml" line="335"/>
        <source>Volume down</source>
        <translation>Тише</translation>
    </message>
    <message>
        <location filename="../src/music-player/dialogs/SettingsDialog.qml" line="379"/>
        <source>Favorite</source>
        <translation>Избранное</translation>
    </message>
    <message>
        <location filename="../src/music-player/dialogs/SettingsDialog.qml" line="501"/>
        <source>Cancel</source>
        <translation>Отменить</translation>
    </message>
    <message>
        <location filename="../src/music-player/dialogs/SettingsDialog.qml" line="534"/>
        <source>Replace</source>
        <translation>Заменить</translation>
    </message>
    <message>
        <location filename="../src/music-player/dialogs/SettingsDialog.qml" line="490"/>
        <source>This shortcut key conflicts with [%1], click Replace to make this shortcut key take effect immediately</source>
        <translation>Этот комбинационный ключ конфликтует с [%1], нажмите Заменить, чтобы сделать этот комбинационный ключ действующим немедленно</translation>
    </message>
</context>
<context>
    <name>Shortcut</name>
    <message>
        <location filename="../src/music-player/util/shortcut.cpp" line="55"/>
        <source>Play</source>
        <translation>Воспроизвести</translation>
    </message>
    <message>
        <location filename="../src/music-player/util/shortcut.cpp" line="56"/>
        <source>Songs</source>
        <translation>Песни</translation>
    </message>
    <message>
        <location filename="../src/music-player/util/shortcut.cpp" line="57"/>
        <source>Playlists</source>
        <translation>Списки воспроизведения</translation>
    </message>
    <message>
        <location filename="../src/music-player/util/shortcut.cpp" line="58"/>
        <source>Settings</source>
        <translation>Настройки</translation>
    </message>
    <message>
        <location filename="../src/music-player/util/shortcut.cpp" line="65"/>
        <source>Play/Pause</source>
        <translation>Воспроизвести/Пауза</translation>
    </message>
    <message>
        <location filename="../src/music-player/util/shortcut.cpp" line="66"/>
        <source>Previous</source>
        <translation>Предыдущий</translation>
    </message>
    <message>
        <location filename="../src/music-player/util/shortcut.cpp" line="67"/>
        <source>Next</source>
        <translation>Следующий</translation>
    </message>
    <message>
        <location filename="../src/music-player/util/shortcut.cpp" line="68"/>
        <source>Volume Up</source>
        <translation>Громче</translation>
    </message>
    <message>
        <location filename="../src/music-player/util/shortcut.cpp" line="69"/>
        <source>Volume Down</source>
        <translation>Тише</translation>
    </message>
    <message>
        <location filename="../src/music-player/util/shortcut.cpp" line="70"/>
        <source>Mute</source>
        <translation>Выключить звук</translation>
    </message>
    <message>
        <location filename="../src/music-player/util/shortcut.cpp" line="73"/>
        <source>Favorite</source>
        <translation>Избранное</translation>
    </message>
    <message>
        <location filename="../src/music-player/util/shortcut.cpp" line="74"/>
        <source>Unfavorite</source>
        <translation>Снять с избранных</translation>
    </message>
    <message>
        <location filename="../src/music-player/util/shortcut.cpp" line="75"/>
        <source>Song info</source>
        <translation>Информация о песне</translation>
    </message>
    <message>
        <location filename="../src/music-player/util/shortcut.cpp" line="78"/>
        <source>New playlist</source>
        <translation>Новый список воспроизведения</translation>
    </message>
    <message>
        <location filename="../src/music-player/util/shortcut.cpp" line="79"/>
        <source>Add music</source>
        <translation>Добавить му音乐</translation>
    </message>
    <message>
        <location filename="../src/music-player/util/shortcut.cpp" line="80"/>
        <source>Rename playlist</source>
        <translation>Переименовать список воспроизведения</translation>
    </message>
    <message>
        <location filename="../src/music-player/util/shortcut.cpp" line="81"/>
        <source>Remove from playlist</source>
        <translation>Удалить из списка воспроизведения</translation>
    </message>
    <message>
        <location filename="../src/music-player/util/shortcut.cpp" line="84"/>
        <source>Help</source>
        <translation>Помощь</translation>
    </message>
    <message>
        <location filename="../src/music-player/util/shortcut.cpp" line="85"/>
        <source>Display shortcuts</source>
        <translation>Показать комбинации</translation>
    </message>
</context>
<context>
    <name>Shortcuts</name>
    <message>
        <location filename="../src/music-player/allItems/Shortcuts.qml" line="51"/>
        <source>New playlist</source>
        <translation>Новый список воспроизведения</translation>
    </message>
    <message>
        <location filename="../src/music-player/allItems/Shortcuts.qml" line="120"/>
        <source>My Favorites</source>
        <translation>Мои избранные</translation>
    </message>
</context>
<context>
    <name>SidebarMenu</name>
    <message>
        <location filename="../src/music-player/musicmousemenu/SidebarMenu.qml" line="22"/>
        <source>Play</source>
        <translation>Воспроизвести</translation>
    </message>
    <message>
        <location filename="../src/music-player/musicmousemenu/SidebarMenu.qml" line="29"/>
        <source>Add songs</source>
        <translation>Добавить песни</translation>
    </message>
    <message>
        <location filename="../src/music-player/musicmousemenu/SidebarMenu.qml" line="38"/>
        <source>Rename</source>
        <translation>Переименовать</translation>
    </message>
    <message>
        <location filename="../src/music-player/musicmousemenu/SidebarMenu.qml" line="52"/>
        <source>Delete</source>
        <translation>Удалить</translation>
    </message>
</context>
<context>
    <name>SortMenu</name>
    <message>
        <location filename="../src/music-player/allItems/SortMenu.qml" line="29"/>
        <source>CD playlist</source>
        <translation>Плейлист CD</translation>
    </message>
    <message>
        <location filename="../src/music-player/allItems/SortMenu.qml" line="33"/>
        <source>Custom</source>
        <translation>Пользовательский</translation>
    </message>
    <message>
        <location filename="../src/music-player/allItems/SortMenu.qml" line="34"/>
        <source>Date added</source>
        <translation>Дата добавления</translation>
    </message>
    <message>
        <location filename="../src/music-player/allItems/SortMenu.qml" line="37"/>
        <source>Album</source>
        <translation>Альбом</translation>
    </message>
    <message>
        <location filename="../src/music-player/allItems/SortMenu.qml" line="36"/>
        <source>Artist</source>
        <translation>Исполнитель</translation>
    </message>
    <message>
        <location filename="../src/music-player/allItems/SortMenu.qml" line="35"/>
        <source>Title</source>
        <translation>Название</translation>
    </message>
</context>
<context>
    <name>SublistTitleButton</name>
    <message>
        <location filename="../src/music-player/allItems/SublistTitleButton.qml" line="54"/>
        <source>1 song</source>
        <translation>1 песня</translation>
    </message>
    <message>
        <location filename="../src/music-player/allItems/SublistTitleButton.qml" line="54"/>
        <source>%1 songs</source>
        <translation>&apos;%1 песни&apos;</translation>
    </message>
    <message>
        <location filename="../src/music-player/allItems/SublistTitleButton.qml" line="64"/>
        <source>Play All</source>
        <translation>Восп. всё</translation>
    </message>
</context>
<context>
    <name>ToolButtonItem</name>
    <message>
        <location filename="../src/music-player/allItems/ToolButtonItem.qml" line="59"/>
        <source>Play All</source>
        <translation>Восп. всё</translation>
    </message>
</context>
<context>
    <name>Toolbar</name>
    <message>
        <location filename="../src/music-player/mainwindow/Toolbar.qml" line="43"/>
        <source>Sequential play</source>
        <translation>Последовательное воспроизведение</translation>
    </message>
    <message>
        <location filename="../src/music-player/mainwindow/Toolbar.qml" line="43"/>
        <source>List loop</source>
        <translation>Цикл списка</translation>
    </message>
    <message>
        <location filename="../src/music-player/mainwindow/Toolbar.qml" line="43"/>
        <source>Single loop</source>
        <translation>Цикл одной песни</translation>
    </message>
    <message>
        <location filename="../src/music-player/mainwindow/Toolbar.qml" line="43"/>
        <source>Shuffle</source>
        <translation>Перемешать</translation>
    </message>
    <message>
        <location filename="../src/music-player/mainwindow/Toolbar.qml" line="207"/>
        <source>Unfavorite</source>
        <translation>Удалить из избранного</translation>
    </message>
    <message>
        <location filename="../src/music-player/mainwindow/Toolbar.qml" line="207"/>
        <source>Favorite</source>
        <translation>Добавить в избранное</translation>
    </message>
    <message>
        <location filename="../src/music-player/mainwindow/Toolbar.qml" line="220"/>
        <source>My Favorites</source>
        <translation>Мои избранные</translation>
    </message>
    <message>
        <location filename="../src/music-player/mainwindow/Toolbar.qml" line="238"/>
        <source>Previous</source>
        <translation>Предыдущая</translation>
    </message>
    <message>
        <location filename="../src/music-player/mainwindow/Toolbar.qml" line="259"/>
        <source>Play/Pause</source>
        <translation>Воспроизвести/Пауза</translation>
    </message>
    <message>
        <location filename="../src/music-player/mainwindow/Toolbar.qml" line="280"/>
        <source>Next</source>
        <translation>Следующая</translation>
    </message>
    <message>
        <location filename="../src/music-player/mainwindow/Toolbar.qml" line="389"/>
        <source>Lyrics</source>
        <translation>Текст песни</translation>
    </message>
    <message>
        <location filename="../src/music-player/mainwindow/Toolbar.qml" line="438"/>
        <source>Play Queue</source>
        <translation>Очередь воспроизведения</translation>
    </message>
</context>
<context>
    <name>WindowTitlebar</name>
    <message>
        <location filename="../src/music-player/mainwindow/WindowTitlebar.qml" line="56"/>
        <source>Add playlist</source>
        <translation>Добавить плейлист</translation>
    </message>
    <message>
        <location filename="../src/music-player/mainwindow/WindowTitlebar.qml" line="58"/>
        <source>New playlist</source>
        <translation>Новый плейлист</translation>
    </message>
    <message>
        <location filename="../src/music-player/mainwindow/WindowTitlebar.qml" line="63"/>
        <source>Add music</source>
        <translation>Добавить музыку</translation>
    </message>
    <message>
        <location filename="../src/music-player/mainwindow/WindowTitlebar.qml" line="71"/>
        <source>Equalizer</source>
        <translation>Эквализатор</translation>
    </message>
    <message>
        <location filename="../src/music-player/mainwindow/WindowTitlebar.qml" line="82"/>
        <source>Settings</source>
        <translation>Настройки</translation>
    </message>
    <message>
        <location filename="../src/music-player/mainwindow/WindowTitlebar.qml" line="96"/>
        <source>Music</source>
        <translation>Музыка</translation>
    </message>
    <message>
        <location filename="../src/music-player/mainwindow/WindowTitlebar.qml" line="98"/>
        <source>Music is a local music player with beautiful design and simple functions.</source>
        <translation>Музыка — это локальный проигрыватель музыки с красивым дизайном и простыми функциями.</translation>
    </message>
    <message>
        <location filename="../src/music-player/mainwindow/WindowTitlebar.qml" line="99"/>
        <source>Version:</source>
        <translation>Версия:</translation>
    </message>
    <message>
        <location filename="../src/music-player/mainwindow/WindowTitlebar.qml" line="213"/>
        <source>Previous page</source>
        <translation>Предыдущая страница</translation>
    </message>
    <message>
        <location filename="../src/music-player/mainwindow/WindowTitlebar.qml" line="229"/>
        <source>Next page</source>
        <translation>Следующая страница</translation>
    </message>
    <message>
        <location filename="../src/music-player/mainwindow/WindowTitlebar.qml" line="239"/>
        <source>Search</source>
        <translation>Поиск</translation>
    </message>
</context>
</TS>